@@ -2,7 +2,6 @@
 Compatibility code
 """
 import atexit
-import distutils.util
 import functools
 import importlib
 import inspect
@@ -503,16 +502,6 @@ def open_file(url, session=None):
                 result.close()
 
 
-def get_platform():
-    """Return our platform name 'win32', 'linux_x86_64'"""
-    # XXX remove distutils dependency
-    result = distutils.util.get_platform().replace(".", "_").replace("-", "_")
-    if result == "linux_x86_64" and sys.maxsize == 2147483647:
-        # pip pull request #3497
-        result = "linux_i686"
-    return result
-
-
 def highest_version(versions: List[str]) -> str:
     """Return the highest version of a given list."""
     return max(versions, key=parse_version)
